/* Copyright (c) 2004 Marijn Haverbeke
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * Marijn Haverbeke
 * marijn(at)haverbeke.nl
 */

// Filler is a class used to draw the image that is being cut up into
// the individual puzzle pieces.

#include <wx/image.h>
#include "filler.hpp"
#include "jigsaw.hpp"

// The constructor rescales the image so it fits width x height
// pieces.
Jigsaw_Filler::Jigsaw_Filler(wxImage& image, int width, int height)
  : _width(width),
    _height(height),
    _image(image)
{
  size_t pixel_width = width * piece_size;
  size_t pixel_height = height * piece_size;
  _image.Rescale(pixel_width, pixel_height);
}

// Blit a piece of the image into the bitmap of a Piece object.
void Jigsaw_Filler::Fill_Piece(Piece* piece)
{
  wxPoint place = piece->Place();

  wxMemoryDC target;
  target.SelectObject(piece->Bitmap());
  wxMemoryDC source;
  source.SelectObject(_image);

  target.Blit(0, 0, picture_size, picture_size, &source, place.x * piece_size - border_size, place.y * piece_size - border_size, wxCOPY);
}
